8173604: Rename module 8173604 java.annotations.common to java.xml.ws.annoations
authorlancea
Sat, 04 Feb 2017 14:05:08 -0500
changeset 43581 af18ebffc685
parent 43580 22134ce68814
child 43582 a6c58d4cb05b
8173604: Rename module 8173604 java.annotations.common to java.xml.ws.annoations Reviewed-by: dfuchs, alanb, psandoz, mchung
langtools/test/tools/javac/modules/AddLimitMods.java
langtools/test/tools/jdeps/modules/SplitPackage.java
--- a/langtools/test/tools/javac/modules/AddLimitMods.java	Fri Feb 03 22:09:30 2017 -0800
+++ b/langtools/test/tools/javac/modules/AddLimitMods.java	Sat Feb 04 14:05:08 2017 -0500
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -217,10 +217,10 @@
 
     private static final List<Entry<String[], String>> variants = Arrays.asList(
             new SimpleEntry<String[], String>(new String[] {},
-                                              "Test.java:2:7: compiler.err.package.not.visible: javax.annotation, (compiler.misc.not.def.access.does.not.read.from.unnamed: javax.annotation, java.annotations.common)\n"
+                                              "Test.java:2:7: compiler.err.package.not.visible: javax.annotation, (compiler.misc.not.def.access.does.not.read.from.unnamed: javax.annotation, java.xml.ws.annotation)\n"
                                             + "Test.java:5:14: compiler.err.package.not.visible: javax.xml.bind, (compiler.misc.not.def.access.does.not.read.from.unnamed: javax.xml.bind, java.xml.bind)\n"
                                             + "2 errors\n"),
-            new SimpleEntry<String[], String>(new String[] {"--add-modules", "java.annotations.common,java.xml.bind"},
+            new SimpleEntry<String[], String>(new String[] {"--add-modules", "java.xml.ws.annotation,java.xml.bind"},
                                               null),
             new SimpleEntry<String[], String>(new String[] {"--limit-modules", "java.xml.ws,jdk.compiler"},
                                               null),
--- a/langtools/test/tools/jdeps/modules/SplitPackage.java	Fri Feb 03 22:09:30 2017 -0800
+++ b/langtools/test/tools/jdeps/modules/SplitPackage.java	Sat Feb 04 14:05:08 2017 -0500
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -51,7 +51,7 @@
     private static final Path CLASSES_DIR = Paths.get("classes");
 
     private static final String SPLIT_PKG_NAME = "javax.annotation";
-    private static final String JAVA_ANNOTATIONS_COMMON = "java.annotations.common";
+    private static final String JAVA_XML_WS_ANNOTATION = "java.xml.ws.annotation";
     /**
      * Compiles classes used by the test
      */
@@ -64,7 +64,7 @@
     @Test
     public void runTest() throws Exception {
         // split package detected if java.annotation.common is in the root set
-        runTest(JAVA_ANNOTATIONS_COMMON, SPLIT_PKG_NAME);
+        runTest(JAVA_XML_WS_ANNOTATION, SPLIT_PKG_NAME);
         runTest("ALL-SYSTEM", SPLIT_PKG_NAME);
         // default
         runTest(null, SPLIT_PKG_NAME);
@@ -98,7 +98,7 @@
                 throw new RuntimeException(splitPackages.toString());
             }
 
             // java.annotations.common is not observable
             DepsAnalyzer analyzer = jdeps.getDepsAnalyzer();
 
             assertTrue(analyzer.run());
@@ -98,7 +98,7 @@
             }
 
-            // java.annotations.common is not observable
+            // java.xml.ws.annotation is not observable
             DepsAnalyzer analyzer = jdeps.getDepsAnalyzer();
 